@@ -1,3 +1,5 @@
+import json
+
 from apiclient_pydantic import serialize_all_methods, serialize_response
 
 from authomize.rest_api_client.client.base_client import BaseClient
@@ -5,6 +7,12 @@ from authomize.rest_api_client.generated.schemas import (
     BundleTransactionSchema,
     ItemsBundleSchema,
     MeResponse,
+    NewGroupMembersRequestSchema,
+    NewGroupMembersResponseSchema,
+    NewGroupRequestSchema,
+    NewGroupResponseSchema,
+    NewUserRequestSchema,
+    NewUserResponseSchema,
     RestApiConnectorListSchema,
     SubmitResponse,
 )
@@ -24,9 +32,9 @@ class Client(BaseClient):
         return self.http_post(f'/v1/connectors/{connector_id}/transactions')
 
     def retrieve_transaction(
-        self,
-        connector_id: str,
-        transaction_id: str
+            self,
+            connector_id: str,
+            transaction_id: str
     ) -> BundleTransactionSchema:
         if not connector_id:
             raise ValueError('Missing connector_id')
@@ -42,10 +50,10 @@ class Client(BaseClient):
         return self.http_post(f'/v1/connectors/{connector_id}/transactions/{transaction_id}/apply')
 
     def extend_transaction_items(
-        self,
-        connector_id: str,
-        transaction_id: str,
-        items: ItemsBundleSchema
+            self,
+            connector_id: str,
+            transaction_id: str,
+            items: ItemsBundleSchema
     ) -> SubmitResponse:
         if not connector_id:
             raise ValueError('Missing connector_id')
@@ -55,3 +63,27 @@ class Client(BaseClient):
             f'/v1/connectors/{connector_id}/transactions/{transaction_id}/items',
             body=items.json()
         )
+
+    def delete_app_data(self, app_id: str):
+        if not app_id:
+            raise ValueError('Missing app_id')
+        return self.http_delete(url=f'/v2/apps/{app_id}/data')
+
+    def create_users(self, app_id: str, body: list[NewUserRequestSchema]) -> NewUserResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        return self.http_post(url=f'/v2/apps/{app_id}/accounts/users', body=json.dumps(body))
+
+    def create_groups(
+            self, app_id: str, body: list[NewGroupRequestSchema]
+    ) -> NewGroupResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        return self.http_post(url=f'/v2/apps/{app_id}/groups', body=json.dumps(body))
+
+    def create_groups_members(
+            self, app_id: str, body: NewGroupMembersRequestSchema
+    ) -> NewGroupMembersResponseSchema:
+        if not app_id:
+            raise ValueError('Missing app_id')
+        return self.http_post(url=f'/v2/apps/{app_id}/groups/members', body=body.json())
